@@ -1,5 +1,5 @@
 generatetonetwork <-
-function(raw, allindivs=union(raw$VertexFrom, raw$VertexTo))
+function(raw, allindivs=union(as.character(raw$VertexFrom), as.character(raw$VertexTo)))
 {
 	vel <- generatetonetworkfromvel(generatevertexedgelist(raw, allindivs))
 	return(vel)
